Design

    Data Model
    Base Model structure
    Versioning
    WidgySite (rationale)
    Owner Contract
    JavaScript (low priority)

Contrib Packages

    Page Builder (list of widgets)
    Form Builder
      - installation (HandleFormMixin)
      - list of widgets
      - Form API
      - success handlers
    Widgy Mezzanine
      - installation
    Review Queue
      - installation / permissions

API Reference

    Model Fields
    Forms/Formfields
    Node API
    Content API
    WidgySite (API)
    Links API


Tutorials

    Tutorial with Widgy Mezzanine
      - start at startproject
      - install Mezzanine
      - end at creating your own widget.
    Creating your first Widget
    Creating a custom widgy owner
      - views
    Creating a component (low priority)
